import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { HomeBannerVO, HomeBannerForm, HomeBannerQuery } from '@/api/home/homeBanner/types';

/**
 * 查询门户Banner列表
 * @param query
 * @returns {*}
 */

export const listHomeBanner = (query?: HomeBannerQuery): AxiosPromise<HomeBannerVO[]> => {
  return request({
    url: '/home/banner/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询门户Banner详细
 * @param bannerId
 */
export const getHomeBanner = (bannerId: string | number): AxiosPromise<HomeBannerVO> => {
  return request({
    url: '/home/banner/' + bannerId,
    method: 'get'
  });
};

/**
 * 新增门户Banner
 * @param data
 */
export const addHomeBanner = (data: HomeBannerForm) => {
  return request({
    url: '/home/banner',
    method: 'post',
    data: data
  });
};

/**
 * 修改门户Banner
 * @param data
 */
export const updateHomeBanner = (data: HomeBannerForm) => {
  return request({
    url: '/home/banner',
    method: 'put',
    data: data
  });
};

/**
 * 修改门户Banner
 * @param data
 */
export const updatStatus = (data: HomeBannerForm) => {
  return request({
    url: '/home/banner/status',
    method: 'put',
    data: data
  });
};

/**
 * 删除门户Banner
 * @param bannerId
 */
export const delHomeBanner = (bannerId: string | number | Array<string | number>) => {
  return request({
    url: '/home/banner/' + bannerId,
    method: 'delete'
  });
};
