import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { HomeShowVO, HomeShowForm, HomeShowQuery } from '@/api/home/homeShow/types';

/**
 * 查询学校名师列表
 * @param query
 * @returns {*}
 */

export const listHomeShow = (query?: HomeShowQuery): AxiosPromise<HomeShowVO[]> => {
  return request({
    url: '/home/show/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询学校名师详细
 * @param showId
 */
export const getHomeShow = (showId: string | number): AxiosPromise<HomeShowVO> => {
  return request({
    url: '/home/show/' + showId,
    method: 'get'
  });
};

/**
 * 新增学校名师
 * @param data
 */
export const addHomeShow = (data: HomeShowForm) => {
  return request({
    url: '/home/show',
    method: 'post',
    data: data
  });
};

/**
 * 修改学校名师
 * @param data
 */
export const updateHomeShow = (data: HomeShowForm) => {
  return request({
    url: '/home/show',
    method: 'put',
    data: data
  });
};

/**
 * 删除学校名师
 * @param showId
 */
export const delHomeShow = (showId: string | number | Array<string | number>) => {
  return request({
    url: '/home/show/' + showId,
    method: 'delete'
  });
};
