import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { HomeTrendVO, HomeTrendForm, HomeTrendQuery } from '@/api/home/homeTrend/types';

/**
 * 查询学校动态列表
 * @param query
 * @returns {*}
 */

export const listHomeTrend = (query?: HomeTrendQuery): AxiosPromise<HomeTrendVO[]> => {
  return request({
    url: '/home/trend/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询学校动态详细
 * @param trendId
 */
export const getHomeTrend = (trendId: string | number): AxiosPromise<HomeTrendVO> => {
  return request({
    url: '/home/trend/' + trendId,
    method: 'get'
  });
};

/**
 * 新增学校动态
 * @param data
 */
export const addHomeTrend = (data: HomeTrendForm) => {
  return request({
    url: '/home/trend',
    method: 'post',
    data: data
  });
};

/**
 * 修改学校动态
 * @param data
 */
export const updateHomeTrend = (data: HomeTrendForm) => {
  return request({
    url: '/home/trend',
    method: 'put',
    data: data
  });
};

/**
 * 删除学校动态
 * @param trendId
 */
export const delHomeTrend = (trendId: string | number | Array<string | number>) => {
  return request({
    url: '/home/trend/' + trendId,
    method: 'delete'
  });
};
