import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { CatalogPersonVO, CatalogPersonForm, CatalogPersonQuery } from '@/api/resource/catalogPerson/types';

/**
 * 查询目录-我的空间列表
 * @param query
 * @returns {*}
 */

export const listCatalogPerson = (query?: CatalogPersonQuery): AxiosPromise<CatalogPersonVO[]> => {
  return request({
    url: '/catalog/person/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询目录-我的空间详细
 * @param catalogId
 */
export const getCatalogPerson = (catalogId: string | number): AxiosPromise<CatalogPersonVO> => {
  return request({
    url: '/catalog/person/' + catalogId,
    method: 'get'
  });
};

/**
 * 新增目录-我的空间
 * @param data
 */
export const addCatalogPerson = (data: CatalogPersonForm) => {
  return request({
    url: '/catalog/person',
    method: 'post',
    data: data
  });
};

/**
 * 修改目录-我的空间
 * @param data
 */
export const updateCatalogPerson = (data: CatalogPersonForm) => {
  return request({
    url: '/catalog/person',
    method: 'put',
    data: data
  });
};

/**
 * 删除目录-我的空间
 * @param catalogId
 */
export const delCatalogPerson = (catalogId: string | number | Array<string | number>) => {
  return request({
    url: '/catalog/person/' + catalogId,
    method: 'delete'
  });
};

export const dragPerson = (data: any) => {
  return request({
    url: '/catalog/person/drag',
    method: 'post',
    data: data
  });
};

export const share = (data: CatalogPersonForm) => {
  return request({
    url: '/oss/person/share',
    method: 'put',
    data: data
  });
};
