import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { CatalogResourceVO, CatalogResourceForm, CatalogResourceQuery } from '@/api/resource/catalogResource/types';

/**
 * 查询目录-专题资源列表
 * @param query
 * @returns {*}
 */

export const listCatalogResource = (query?: CatalogResourceQuery): AxiosPromise<CatalogResourceVO[]> => {
  return request({
    url: '/catalog/resource/list',
    method: 'get',
    params: query
  });
};

export const pageCatalogResource = (query?: CatalogResourceQuery): AxiosPromise<CatalogResourceVO[]> => {
  return request({
    url: '/catalog/resource/pageList',
    method: 'get',
    params: query
  });
};


/**
 * 查询目录-专题资源详细
 * @param catalogId
 */
export const getCatalogResource = (catalogId: string | number): AxiosPromise<CatalogResourceVO> => {
  return request({
    url: '/catalog/resource/' + catalogId,
    method: 'get'
  });
};

/**
 * 新增目录-专题资源
 * @param data
 */
export const addCatalogResource = (data: CatalogResourceForm) => {
  return request({
    url: '/catalog/resource',
    method: 'post',
    data: data
  });
};

/**
 * 修改目录-专题资源
 * @param data
 */
export const updateCatalogResource = (data: CatalogResourceForm) => {
  return request({
    url: '/catalog/resource',
    method: 'put',
    data: data
  });
};

/**
 * 删除目录-专题资源
 * @param catalogId
 */
export const delCatalogResource = (catalogId: string | number | Array<string | number>) => {
  return request({
    url: '/catalog/resource/' + catalogId,
    method: 'delete'
  });
};

export const dragResource = (data: any) => {
  return request({
    url: '/catalog/resource/drag',
    method: 'post',
    data: data
  });
};