import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { CatalogTextbookVO, CatalogTextbookForm, CatalogTextbookQuery } from '@/api/resource/catalogTextbook/types';

/**
 * 查询目录-同步教材列表
 * @param query
 * @returns {*}
 */

export const listCatalogTextbook = (query?: CatalogTextbookQuery): AxiosPromise<CatalogTextbookVO[]> => {
  return request({
    url: '/catalog/textbook/list',
    method: 'get',
    params: query
  });
};

export const pageCatalogTextbook = (query?: CatalogTextbookQuery): AxiosPromise<CatalogTextbookVO[]> => {
  return request({
    url: '/catalog/textbook/pageList',
    method: 'get',
    params: query
  });
};

/**
 * 查询目录-同步教材详细
 * @param catalogId
 */
export const getCatalogTextbook = (catalogId: string | number): AxiosPromise<CatalogTextbookVO> => {
  return request({
    url: '/catalog/textbook/' + catalogId,
    method: 'get'
  });
};

/**
 * 新增目录-同步教材
 * @param data
 */
export const addCatalogTextbook = (data: CatalogTextbookForm) => {
  return request({
    url: '/catalog/textbook',
    method: 'post',
    data: data
  });
};

/**
 * 修改目录-同步教材
 * @param data
 */
export const updateCatalogTextbook = (data: CatalogTextbookForm) => {
  return request({
    url: '/catalog/textbook',
    method: 'put',
    data: data
  });
};

/**
 * 删除目录-同步教材
 * @param catalogId
 */
export const delCatalogTextbook = (catalogId: string | number | Array<string | number>) => {
  return request({
    url: '/catalog/textbook/' + catalogId,
    method: 'delete'
  });
};


export const dragTextbook = (data: any) => {
  return request({
    url: '/catalog/textbook/drag',
    method: 'post',
    data: data
  });
};