import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { TeacherVO, TeacherForm, TeacherQuery } from '@/api/teacher/types';

/**
 * 查询教职工信息列表
 * @param query
 * @returns {*}
 */

export const pageTeacher = (query?: TeacherQuery): AxiosPromise<TeacherVO[]> => {
  return request({
    url: '/teacher/pageList',
    method: 'get',
    params: query
  });
};

export const listTeacher = (query?: TeacherQuery): AxiosPromise<TeacherVO[]> => {
  return request({
    url: '/teacher/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询教职工信息详细
 * @param teacherId
 */
export const getTeacher = (teacherId: string | number): AxiosPromise<TeacherVO> => {
  return request({
    url: '/teacher/' + teacherId,
    method: 'get'
  });
};

/**
 * 新增教职工信息
 * @param data
 */
export const addTeacher = (data: TeacherForm) => {
  return request({
    url: '/teacher',
    method: 'post',
    data: data
  });
};

/**
 * 修改教职工信息
 * @param data
 */
export const updateTeacher = (data: TeacherForm) => {
  return request({
    url: '/teacher',
    method: 'put',
    data: data
  });
};

/**
 * 删除教职工信息
 * @param teacherId
 */
export const delTeacher = (teacherId: string | number | Array<string | number>) => {
  return request({
    url: '/teacher/' + teacherId,
    method: 'delete'
  });
};
